summaryrefslogtreecommitdiffstats
path: root/amarok/src/debug.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-08-20 06:53:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-08-20 06:53:52 +0000
commit3a09386ad170dafdce88c5dcd70275cc7d4081e9 (patch)
tree0f9544da38cdb9c5cc20ad9d695588413b4cd5f9 /amarok/src/debug.h
parent36a9c1916513474b11c59a9060cbaf8770d1bbc0 (diff)
downloadamarok-3a09386ad170dafdce88c5dcd70275cc7d4081e9.tar.gz
amarok-3a09386ad170dafdce88c5dcd70275cc7d4081e9.zip
Initial TQt conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/amarok@1165727 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'amarok/src/debug.h')
-rw-r--r--amarok/src/debug.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/amarok/src/debug.h b/amarok/src/debug.h
index 2c83ad79..610704fe 100644
--- a/amarok/src/debug.h
+++ b/amarok/src/debug.h
@@ -6,14 +6,14 @@
#define AMAROK_DEBUG_H
#include <kdebug.h>
-#include <qcstring.h>
-#include <qdeepcopy.h>
-#include <qmutex.h>
-#include <qobject.h>
+#include <tqcstring.h>
+#include <tqdeepcopy.h>
+#include <tqmutex.h>
+#include <tqobject.h>
#include <sys/time.h>
-class QApplication;
-extern QApplication *qApp; ///@see Debug::Indent
+class TQApplication;
+extern TQApplication *qApp; ///@see Debug::Indent
/**
@@ -48,30 +48,30 @@ extern QApplication *qApp; ///@see Debug::Indent
namespace Debug
{
- extern QMutex mutex; // defined in app.cpp
+ extern TQMutex mutex; // defined in app.cpp
- // we can't use a statically instantiated QCString for the indent, because
+ // we can't use a statically instantiated TQCString for the indent, because
// static namespaces are unique to each dlopened library. So we piggy back
// the QCString on the KApplication instance
#define qApp reinterpret_cast<QObject*>(qApp)
class Indent : QObject
{
- friend QCString &modifieableIndent();
- Indent() : QObject( qApp, "DEBUG_indent" ) {}
- QCString m_string;
+ friend TQCString &modifieableIndent();
+ Indent() : TQObject( qApp, "DEBUG_indent" ) {}
+ TQCString m_string;
};
- inline QCString &modifieableIndent()
+ inline TQCString &modifieableIndent()
{
- QObject *o = qApp ? qApp->child( "DEBUG_indent" ) : 0;
- QCString &ret = (o ? static_cast<Indent*>( o ) : new Indent)->m_string;
+ TQObject *o = qApp ? qApp->child( "DEBUG_indent" ) : 0;
+ TQCString &ret = (o ? static_cast<Indent*>( o ) : new Indent)->m_string;
return ret;
}
- inline QCString indent()
+ inline TQCString indent()
{
- return QDeepCopy<QCString>( modifieableIndent() );
+ return TQDeepCopy<TQCString>( modifieableIndent() );
}
#undef qApp
@@ -98,10 +98,10 @@ namespace Debug
KDEBUG_FATAL = 3
};
- static inline kdbgstream debug() { mutex.lock(); QCString ind = indent(); mutex.unlock(); return kdbgstream( ind, 0, KDEBUG_INFO ) << AMK_PREFIX; }
- static inline kdbgstream warning() { mutex.lock(); QCString ind = indent(); mutex.unlock(); return kdbgstream( ind, 0, KDEBUG_WARN ) << AMK_PREFIX << "[WARNING!] "; }
- static inline kdbgstream error() { mutex.lock(); QCString ind = indent(); mutex.unlock(); return kdbgstream( ind, 0, KDEBUG_ERROR ) << AMK_PREFIX << "[ERROR!] "; }
- static inline kdbgstream fatal() { mutex.lock(); QCString ind = indent(); mutex.unlock(); return kdbgstream( ind, 0, KDEBUG_FATAL ) << AMK_PREFIX; }
+ static inline kdbgstream debug() { mutex.lock(); TQCString ind = indent(); mutex.unlock(); return kdbgstream( ind, 0, KDEBUG_INFO ) << AMK_PREFIX; }
+ static inline kdbgstream warning() { mutex.lock(); TQCString ind = indent(); mutex.unlock(); return kdbgstream( ind, 0, KDEBUG_WARN ) << AMK_PREFIX << "[WARNING!] "; }
+ static inline kdbgstream error() { mutex.lock(); TQCString ind = indent(); mutex.unlock(); return kdbgstream( ind, 0, KDEBUG_ERROR ) << AMK_PREFIX << "[ERROR!] "; }
+ static inline kdbgstream fatal() { mutex.lock(); TQCString ind = indent(); mutex.unlock(); return kdbgstream( ind, 0, KDEBUG_FATAL ) << AMK_PREFIX; }
typedef kdbgstream DebugStream;
@@ -193,7 +193,7 @@ namespace Debug
Debug::modifieableIndent().truncate( Debug::indent().length() - 2 );
kdDebug() << "END__: " << m_label
- << " - Took " << QString::number( duration, 'g', 2 ) << "s\n";
+ << " - Took " << TQString::number( duration, 'g', 2 ) << "s\n";
mutex.unlock();
}
};
@@ -228,7 +228,7 @@ namespace Debug
}
-#include <qvariant.h>
+#include <tqvariant.h>
namespace Debug
{
@@ -239,7 +239,7 @@ namespace Debug
* debug() << (Debug::List() << anInt << aString << aQStringList << aDouble) << endl;
*/
- typedef QValueList<QVariant> List;
+ typedef TQValueList<TQVariant> List;
}
#endif
@@ -48,30 +48,30 @@ extern QApplication *qApp; ///@see Debug::Indent
// static namespaces are unique to each dlopened library. So we piggy back
- // the QCString on the KApplication instance
+ // the TQCString on the KApplication instance
- #define qApp reinterpret_cast<QObject*>(qApp)
+ #define qApp reinterpret_cast<TQObject*>(qApp)
class Indent : QObject
{